@@ -3,8 +3,8 @@
 %  This file is part of Logtalk <http://logtalk.org/>  
 %  Copyright (c) 1998-2015 Paulo Moura <pmoura@logtalk.org>
 %
-%  Adapter file for JIProlog 4.0.6 or later versions
-%  Last updated on February 24, 2015
+%  Adapter file for JIProlog 4.0.14 or later versions
+%  Last updated on May 10, 2015
 %
 %  This program is free software: you can redistribute it and/or modify
 %  it under the terms of the GNU General Public License as published by
@@ -25,6 +25,9 @@
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
 
+:- set_prolog_flag(unknown, error).
+
+
 
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
@@ -156,10 +159,10 @@ format(Format, Arguments) :-
 
 % '$lgt_prolog_meta_predicate'(@callable, ?callable, ?atom)
 
-'$lgt_prolog_meta_predicate'(checklist(_,_), checklist(1,*), predicate).
-'$lgt_prolog_meta_predicate'(maplist(_,_,_), maplist(2,*,*), predicate).
-'$lgt_prolog_meta_predicate'(not(_), not(0), predicate).
-'$lgt_prolog_meta_predicate'(one(_), one(0), predicate).
+'$lgt_prolog_meta_predicate'(Callable, Template, predicate) :-
+	predicate_property(Callable, meta_predicate(Template)),
+	predicate_property(Callable, built_in),
+	!.
 
 
 % '$lgt_prolog_meta_directive'(@callable, -callable)
@@ -222,10 +225,10 @@ format(Format, Arguments) :-
 '$lgt_prolog_feature'(prolog_dialect, ji).
 '$lgt_prolog_feature'(prolog_version, (Major, Minor, Patch)) :-
 	current_prolog_flag(version_data, jiprolog(Major, Minor, Patch, _)).
-'$lgt_prolog_feature'(prolog_compatible_version, @>=((4,0,6))).
-'$lgt_prolog_feature'(prolog_conformance, iso_lax).
+'$lgt_prolog_feature'(prolog_compatible_version, @>=((4,0,14))).
+'$lgt_prolog_feature'(prolog_conformance, lax).
 
-'$lgt_prolog_feature'(encoding_directive, unsupported).
+'$lgt_prolog_feature'(encoding_directive, source).
 '$lgt_prolog_feature'(tabling, unsupported).
 '$lgt_prolog_feature'(threads, unsupported).
 '$lgt_prolog_feature'(modules, unsupported).
@@ -385,7 +388,8 @@ format(Format, Arguments) :-
 % changes current working directory
 
 '$lgt_change_directory'(Directory) :-
-	chdir(Directory).
+	'$lgt_expand_path'(Directory, Expanded),
+	chdir(Expanded).
 
 
 % '$lgt_make_directory'(+atom)
@@ -393,9 +397,10 @@ format(Format, Arguments) :-
 % makes a new directory; succeeds if the directory already exists
 
 '$lgt_make_directory'(Directory) :-
-	(	exists_directory(Directory) ->
+	'$lgt_expand_path'(Directory, Expanded),
+	(	exists_directory(Expanded) ->
 		true
-	;	make_directory(Directory)
+	;	make_directory(Expanded)
 	).
 
 
@@ -499,7 +504,8 @@ format(Format, Arguments) :-
 % '$lgt_stream_current_line_number'(@stream, -integer)
 
 '$lgt_stream_current_line_number'(Stream, Line) :-
-	stream_property(Stream, position(line(Line))).
+	stream_property(Stream, position(Position)),
+	stream_position_data(line_count, Position, Line).
 
 
 
@@ -536,10 +542,7 @@ format(Format, Arguments) :-
 % '$lgt_read_term'(@stream, -term, +list, -position, -list)
 
 '$lgt_read_term'(Stream, Term, Options, LineBegin-LineEnd, Variables) :-
-	stream_property(Stream, position(line(LineBegin))),
-	read_term(Stream, Term, Options),
-	stream_property(Stream, position(line(LineEnd))),
-	term_variables(Term, Variables).
+	read_term(Stream, Term, [line_counts(LineBegin,LineEnd), variable_names(Variables)| Options]).
 
 
 
@@ -572,8 +575,8 @@ format(Format, Arguments) :-
 
 % '$lgt_logtalk_prolog_encoding'(?atom, ?atom, +stream)
 
-'$lgt_logtalk_prolog_encoding'(_, _, _) :-
-	fail.
+'$lgt_logtalk_prolog_encoding'('UTF-8', 'UTF-8', _).
+'$lgt_logtalk_prolog_encoding'('US-ASCII', 'US-ASCII', _).
 
 
 
