@@ -4,7 +4,7 @@
 %  Copyright (c) 1998-2015 Paulo Moura <pmoura@logtalk.org>
 %
 %  Adapter file for XSB 3.5.0 or later versions
-%  Last updated on February 16, 2015
+%  Last updated on May 12, 2015
 %
 %  This program is free software: you can redistribute it and/or modify
 %  it under the terms of the GNU General Public License as published by
@@ -105,15 +105,15 @@
 % setup_call_cleanup(+callable, +callable, +callable)
 
 setup_call_cleanup(Setup, Call, Cleanup) :-
-	call(Setup),
-	call_cleanup(Call, Cleanup).
+	once(Setup),
+	call_cleanup(Call, catch(Cleanup,_,true)).
 
 
 % setup_call_catcher_cleanup(+callable, +callable, ?term, +callable)
 
 setup_call_catcher_cleanup(Setup, Call, Catcher, Cleanup) :-
-	call(Setup),
-	catch(Call, Catcher, Cleanup).
+	once(Setup),
+	catch(Call, Catcher, catch(Cleanup,_,true)).
 
 
 
@@ -218,7 +218,7 @@ setup_call_catcher_cleanup(Setup, Call, Catcher, Cleanup) :-
 '$lgt_prolog_feature'(prolog_version, (Major, Minor, Patch)) :-
 	current_prolog_flag(version_data, xsb(Major, Minor, Patch, _)).
 '$lgt_prolog_feature'(prolog_compatible_version, @>=((3,5,0))).
-'$lgt_prolog_feature'(prolog_conformance, iso_lax).
+'$lgt_prolog_feature'(prolog_conformance, lax).
 
 '$lgt_prolog_feature'(encoding_directive, unsupported).
 '$lgt_prolog_feature'(tabling, supported).
